pub struct KubeapiOptions {
pub cache_dir: Option<PathBuf>,
pub as_user: Option<String>,
pub as_group: Option<Vec<String>>,
pub as_uid: Option<String>,
}Fields
cache_dir: Option<PathBuf>Default cache directory
as_user: Option<String>Username to impersonate for the operation. User could be a regular user or a service account in a namespace.
as_group: Option<Vec<String>>Group to impersonate for the operation, this flag can be repeated to specify multiple groups.
as_uid: Option<String>UID to impersonate for the operation.
Implementations
Sourceimpl KubeapiOptions
impl KubeapiOptions
pub fn cache_dir(&self) -> PathBuf
pub fn discovery_cache_for_config( &self, config: &Config, ) -> Result<PathBuf, KubeconfigError>